
# Slot: type




URI: [ks:type](https://w3id.org/linkml/tests/kitchen_sink/type)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children

 *  [FamilialRelationship➞type](FamilialRelationship_type.md)

## Used by

 * [Relationship](Relationship.md)
